#!/usr/bin/env sh
# DESCRIPTION: 'git diff', prompt y/n if 'git add'
# ARGUMENTS: git-diffadd file1 file2 file3 ...
# DEPENDENCIES: git

if [ "$1" = "-h" ] || [ "$1" = "--help" ]
then
	echo "usage: git-diffadd FILE..."
	echo ""
	echo "Preview the 'git diff' of all specified paths (FILE...)"
	echo "and prompt y/n if 'git add' should be run on the file."
	echo "If no FILE... targets are provided, all un-added files"
	echo "will be used"
	exit
fi

pradd() {
	git diff "$dir/$f"

	yn=""
	while [ "$yn" = "" ]; do
		printf "git add '%s' (y/n)? " "$f"
		read -r yn
		if [ "$yn" = "y" ]
		then git add "$f"
		elif [ "$yn" != "n" ]
		then yn=""; fi
	done
}

dir="."
if [ ! "$(git rev-parse --show-toplevel)" ]
then
  echo "'git rev-parse --show-toplevel' failed to return repo root dir at '$(pwd)'"
  exit 1
else
  dir="$(pwd)"
fi

n=0
for f in "$@"
do
	n=$((n+1))
    pradd "$dir/$f"
done

if [ $n -eq 0 ]
then
	for f in $(git ls-files -m)
	do
		pradd "$f"
	done
fi

